<!--

@license Apache-2.0

Copyright (c) 2023 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# Support

> How to get help with stdlib.

This document explains how to get help with stdlib. Please read through the following guidelines.

> 👉 Note: before participating in our community, please read our [Code of Conduct][stdlib-code-of-conduct]. By interacting with this repository, organization, or community, you agree to abide by its terms.

## Getting Help

Please seek support in the following ways:

-   **Bugs**: if you have found a bug or would like to make a specific feature request, please file an issue on the stdlib [issue tracker][stdlib-issues].
-   **Security vulnerabilities**: if you would like to report a security vulnerability, please consult the stdlib [security policy][stdlib-security] and follow requested steps for responsible [disclosure][stdlib-security].
-   **Questions**: for general questions (i.e., concerns which are **not** bug reports or explicit feature requests), please ask on either [GitHub discussions][stdlib-discussions] or on [Gitter][stdlib-gitter].

Please do **not** file issues on the issue tracker seeking help or support debugging your application or open-source project when the encountered issues are specific to your project. You will have better luck in such instances seeking help from other users of stdlib via Stack Overflow or other non-stdlib affiliated public forums.

* * *

### Asking Quality Questions

Help us help you! Be sure to spend time framing questions and to provide links and other resources. Spending extra time at the outset can help save everyone time in the long run.

When seeking help, you are encouraged to adhere to the following principles in order to increase the likelihood of receiving a successful response:

-   **Read documentation and other guides** for the project to see if you can answer the question or figure out the issue on your own. Try locating an example project, and explore how the project works to see if you can answer your question.

-   **Search for existing questions and answers** by consulting the stdlib [issue tracker][stdlib-issues], [discussions][stdlib-discussions], and [FAQ][stdlib-faq]. For debugging issues specific to your project or figuring out how to use stdlib in a manner unique to your application, search for answers and ask questions on Stack Overflow.

-   **Try ["rubber ducking"][rubber-duck-debugging]** to see if verbalizing and discussing the problem helps reveal or challenge any of your current assumptions.

-   **Ensure that you ask about your actual problem** and not your attempted solution (i.e., do not fall prey to the [XY problem][xy-problem]).

-   **Define what you need help with** by asking the following questions:

    -   Are you confronted with a concept that you do not understand? If so, consider engaging more deeply with project documentation and seeking out example projects from which you can learn.
    -   What are you specifically wanting to do? The more specific you are, the more targeted your response.
    -   What problem are you encountering? The more granular you are in terms of circumstances, the more quickly others can reproduce the issue.
    -   What steps have you taken to try and fix the problem? If you have settled on a particular solution, explain why the other attempts have failed.

-   **Provide sample code**, but do not attach your entire project for someone else to debug. Instead, provide a minimal reproducible example of the issue you are encountering.

-   **Prefer providing code and error messages as text** rather than screenshots. While screenshots can be useful, maintainers will benefit from being to engage directly with important text, especially when attempting to reproduce the encountered issue.

-   **Proofread and cross-check** your question to ensure that your question is communicated as clearly as possible.

-   **Do not open duplicate issues** or litter an existing issue with separate "+1" comments. If you want to "upvote" an issue or comment, instead of posting a separate comment, use GitHub's built-in [reaction support][github-reactions] to record a 👍 emoji response.

-   **Do not e-mail (or reach out to via social media) specific project authors or contributors** asking for help debugging your project or application. Please be respectful of maintainer time, and respect that maintainers are likely to have other obligations outside of stdlib.

* * *

## Contributing

If you are interested in contributing to stdlib, please see the stdlib [contributing guide][stdlib-contributing] for guidance on how to contribute.

* * *

## Attribution

This policy document draws from the following support documents:

-   [remark][remark-support]

## License

This document may be reused under a [Creative Commons Attribution-ShareAlike 4.0 International (CC BY-SA 4.0) license][cc-by-sa-4.0].

## Copyright

Copyright © The Stdlib [Authors][stdlib-authors].

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-code-of-conduct]: https://github.com/stdlib-js/stdlib/blob/develop/CODE_OF_CONDUCT.md

[stdlib-discussions]: https://github.com/stdlib-js/stdlib/discussions

[stdlib-gitter]: https://gitter.im/stdlib-js/stdlib

[stdlib-issues]: https://github.com/stdlib-js/stdlib/issues

[stdlib-security]: https://github.com/stdlib-js/stdlib/security

[stdlib-faq]: https://github.com/stdlib-js/stdlib/blob/develop/FAQ.md

[stdlib-contributing]: https://github.com/stdlib-js/stdlib/blob/develop/CONTRIBUTING.md

[rubber-duck-debugging]: https://rubberduckdebugging.com/

[xy-problem]: https://meta.stackexchange.com/questions/66377/what-is-the-xy-problem/66378#66378

[remark-support]: https://github.com/remarkjs/.github/blob/8070442fde16e2c81f80bd65caab6d3a8cc090f4/support.md

[github-reactions]: https://github.blog/2016-03-10-add-reactions-to-pull-requests-issues-and-comments/

[cc-by-sa-4.0]: https://creativecommons.org/licenses/by-sa/4.0/

</section>

<!-- /.links -->
